==> components-1.2.0.tgz: package/es/DropBox/DropBox.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useRef, Fragment, useContext } from 'react';
import FocusScope from '@zohodesk/a11y/es/FocusScope/FocusScope';
import Modal from '../Modal/Modal';
import { getLibraryConfig } from '../Provider/Config';
import LibraryContext from '../Provider/LibraryContextInit';
import cssJSLogic from './css/cssJSLogic';
import DropBoxElement from './DropBoxElement/DropBoxElement';
import { DropBoxDefaultProps } from './props/defaultProps';
import { DropBoxPropTypes } from './props/propTypes';
import { stopPropagation } from './../utils/Common';
import style from './css/DropBox.module.css';
export default function DropBox(props) {
  const dropBoxRef = useRef(null);
  const DropBoxContext = useContext(LibraryContext);
  const {
    needResponsive,
    portalId,
    isActive,
    isAbsolutePositioningNeeded,
    isRestrictScroll,
    needFocusScope,
    onClose,
    customProps
  } = props;
  const {
    focusScopeProps = {}
  } = customProps;
  const {
    autoFocus = true,
    restoreFocus = true,
    needArrowLoop = true,
    needTabLoop = false,
    enableEnterAction = true
  } = focusScopeProps;
  const {
    direction
  } = DropBoxContext || {};
  let windowWidth,
      mobileWidth = getLibraryConfig('mobileWidth'),
      isModel = false;

  if (needResponsive) {
    windowWidth = window.innerWidth;

    if (windowWidth <= mobileWidth) {
      isModel = true;
    }
  }

  const {
    zIndexStyle
  } = cssJSLogic(props);
  const dropBoxEle = needFocusScope ? /*#__PURE__*/React.createElement(FocusScope, _extends({
    onClose: onClose,
    elementRef: dropBoxRef,
    autoFocus: autoFocus,
    restoreFocus: restoreFocus,
    needArrowLoop: needArrowLoop,
    needTabLoop: needTabLoop,
    enableEnterAction: enableEnterAction
  }, focusScopeProps), /*#__PURE__*/React.createElement(DropBoxElement, _extends({
    isModel: isModel,
    direction: direction
  }, props, {
    zIndexStyle: zIndexStyle,
    subContainerRef: dropBoxRef
  }))) : /*#__PURE__*/React.createElement(DropBoxElement, _extends({
    isModel: isModel,
    subContainerRef: dropBoxRef,
    direction: direction
  }, props, {
    zIndexStyle: zIndexStyle
  }));
  return isModel && isActive ? /*#__PURE__*/React.createElement(Modal, {
    portalId: portalId
  }, /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: `${style.freezeLayer} ${style.freeze}`,
    style: zIndexStyle,
    onClick: stopPropagation
  }), dropBoxEle)) : !isAbsolutePositioningNeeded && isActive ? /*#__PURE__*/React.createElement(Modal, {
    portalId: portalId
  }, /*#__PURE__*/React.createElement(React.Fragment, null, isRestrictScroll ? /*#__PURE__*/React.createElement("div", {
    className: style.freezeLayer,
    style: zIndexStyle,
    onClick: stopPropagation
  }) : null, dropBoxEle)) : dropBoxEle;
}
DropBox.propTypes = DropBoxPropTypes;
DropBox.defaultProps = DropBoxDefaultProps;

==> components-1.2.13.tgz: package/es/DropBox/DropBox.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useRef, Fragment, useContext } from 'react';
import FocusScope from '@zohodesk/a11y/es/FocusScope/FocusScope';
import Modal from '../Modal/Modal';
import { getLibraryConfig } from '../Provider/Config';
import LibraryContext from '../Provider/LibraryContextInit';
import cssJSLogic from './css/cssJSLogic';
import DropBoxElement from './DropBoxElement/DropBoxElement';
import { DropBoxDefaultProps } from './props/defaultProps';
import { DropBoxPropTypes } from './props/propTypes';
import { stopPropagation } from './../utils/Common';
import style from './css/DropBox.module.css';
export default function DropBox(props) {
  const dropBoxRef = useRef(null);
  const DropBoxContext = useContext(LibraryContext);
  const {
    needResponsive,
    portalId,
    isActive,
    isAbsolutePositioningNeeded,
    isRestrictScroll,
    needFocusScope,
    onClose,
    customProps
  } = props;
  const {
    focusScopeProps = {}
  } = customProps;
  const {
    needAutoFocus = true,
    needRestoreFocus = true,
    needListNavigation = true,
    needFocusLoop = false,
    needEnterAction = true
  } = focusScopeProps;
  const {
    direction
  } = DropBoxContext || {};
  let windowWidth,
      mobileWidth = getLibraryConfig('mobileWidth'),
      isModel = false;

  if (needResponsive) {
    windowWidth = window.innerWidth;

    if (windowWidth <= mobileWidth) {
      isModel = true;
    }
  }

  const {
    zIndexStyle
  } = cssJSLogic(props);
  const dropBoxEle = needFocusScope ? /*#__PURE__*/React.createElement(FocusScope, _extends({
    onClose: onClose,
    elementRef: dropBoxRef,
    needAutoFocus: needAutoFocus,
    needRestoreFocus: needRestoreFocus,
    needListNavigation: needListNavigation,
    needFocusLoop: needFocusLoop,
    needEnterAction: needEnterAction
  }, focusScopeProps), /*#__PURE__*/React.createElement(DropBoxElement, _extends({
    isModel: isModel,
    direction: direction
  }, props, {
    zIndexStyle: zIndexStyle,
    subContainerRef: dropBoxRef
  }))) : /*#__PURE__*/React.createElement(DropBoxElement, _extends({
    isModel: isModel,
    subContainerRef: dropBoxRef,
    direction: direction
  }, props, {
    zIndexStyle: zIndexStyle
  }));
  return isModel && isActive ? /*#__PURE__*/React.createElement(Modal, {
    portalId: portalId
  }, /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: `${style.freezeLayer} ${style.freeze}`,
    style: zIndexStyle,
    onClick: stopPropagation
  }), dropBoxEle)) : !isAbsolutePositioningNeeded && isActive ? /*#__PURE__*/React.createElement(Modal, {
    portalId: portalId
  }, /*#__PURE__*/React.createElement(React.Fragment, null, isRestrictScroll ? /*#__PURE__*/React.createElement("div", {
    className: style.freezeLayer,
    style: zIndexStyle,
    onClick: stopPropagation
  }) : null, dropBoxEle)) : dropBoxEle;
}
DropBox.propTypes = DropBoxPropTypes;
DropBox.defaultProps = DropBoxDefaultProps;
